@@ -3,6 +3,7 @@
 """Utilities for the resolver."""
 
 import collections.abc
+import logging
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -11,6 +12,7 @@ from typing import (
     Mapping,
     Optional,
     Sequence,
+    Tuple,
     Type,
     TypeVar,
     Union,
@@ -38,8 +40,11 @@ __all__ = [
     "upgrade_to_sequence",
     "make_callback",
     "same_module",
+    "normalize_with_default",
 ]
 
+logger = logging.getLogger(__name__)
+
 X = TypeVar("X")
 Y = TypeVar("Y")
 
@@ -129,3 +134,41 @@ def make_callback(f: Callable[[X], Y]) -> Callable[["click.Context", "click.Para
         return f(value)
 
     return _callback
+
+
+def normalize_with_default(
+    choice: HintOrType[X],
+    kwargs: OptionalKwargs = None,
+    default: HintOrType[X] = None,
+    default_kwargs: OptionalKwargs = None,
+) -> Tuple[HintOrType[X], OptionalKwargs]:
+    """
+    Normalize a choice for class resolver, with default options.
+
+    :param choice:
+        the choice. If None, use the default instead.
+    :param kwargs:
+        the keyword-based parameters for instantiation. Will only be used if choice is *not* None.
+    :param default:
+        the default choice. Used of choice=None.
+    :param default_kwargs:
+        the default keyword-based parameters
+
+    :raises ValueError:
+        if choice and default both are None
+
+    :return:
+        a pair (hint, optional kwargs).
+    """
+    if choice is None:
+        if default is None:
+            raise ValueError("If choice is None, a default has to be provided.")
+        choice = default
+        if kwargs is not None:
+            logger.warning(
+                f"No choice was provided, but kwargs={kwargs} is not None. Will use the default choice={default} "
+                f"with its default_kwargs={default_kwargs}. If you want the explicitly provided kwargs to be used,"
+                f" explicitly provide choice={default} instead of None."
+            )
+        kwargs = default_kwargs
+    return choice, kwargs
